@@ -337,14 +337,14 @@ class fock_space_kron:
             current_state = current_state[:j] + (current_state[j]+1,)
             n += 1
             
-            while n > f2.global_exc or m > f1.global_exc or current_state[j] >= self.local_exc1[j]:
+            while n > self.f2.global_exc or m > self.f1.global_exc or current_state[j] >= self.local_exc1[j]:
                 j -= 1
                 if j < 0:
                     return
-                if j == (f1.modes-1):
+                if j == (self.f1.modes-1):
                     n -= current_state[j+1]
                     m += 1
-                elif j<(f1.modes-1):
+                elif j<(self.f1.modes-1):
                     m -= current_state[j+1] - 1
                 else:
                     n -= current_state[j+1] - 1
@@ -371,10 +371,10 @@ class fock_space_kron:
                 j -= 1
                 if j < 0:
                     return
-                if j == (f1.modes-1):
+                if j == (self.f1.modes-1):
                     n -= current_state[j+1]
                     m += 1
-                elif j<(f1.modes-1):
+                elif j<(self.f1.modes-1):
                     m -= current_state[j+1] - 1
                 else:
                     n -= current_state[j+1] - 1
@@ -385,9 +385,9 @@ class fock_space_kron:
         rho = psi1.conj().T @ psi1
         
         N = int(self.local_exc[k])
-        N1 = f1.global_exc
-        N2 = f2.global_exc
-        border = f1.modes
+        N1 = self.f1.global_exc
+        N2 = self.f2.global_exc
+        border = self.f1.modes
         
         result = np.zeros((N+1,N+1), dtype = complex)
         for p in range(N+1):
@@ -516,6 +516,7 @@ def real_time_solver(psi0, dt, tmax, H, Q = None, final_state = None):
     
         
         
+        
 
 
 # In[ ]:
